==> jc-1.4.0.tar.gz: java/lang/NoSuchFieldException.h <==
// public class java.lang.NoSuchFieldException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class b466c3d2a1fb976d java_lang_NoSuchFieldException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_lang_NoSuchFieldException_H_
#define _JC_java_lang_NoSuchFieldException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_NoSuchFieldException$sub_refs	_jc_java_lang_NoSuchFieldException$sub_refs;
typedef struct _jc_java_lang_NoSuchFieldException$sub_nonrefs	_jc_java_lang_NoSuchFieldException$sub_nonrefs;
typedef struct _jc_java_lang_NoSuchFieldException$refs	_jc_java_lang_NoSuchFieldException$refs;
typedef struct _jc_java_lang_NoSuchFieldException$nonrefs	_jc_java_lang_NoSuchFieldException$nonrefs;
typedef struct _jc_java_lang_NoSuchFieldException$object	_jc_java_lang_NoSuchFieldException$object;

typedef struct _jc_java_lang_NoSuchFieldException$fields_struct	_jc_java_lang_NoSuchFieldException$fields_struct;
typedef const struct _jc_java_lang_NoSuchFieldException$vmethods	_jc_java_lang_NoSuchFieldException$vmethods;
typedef const struct _jc_java_lang_NoSuchFieldException$vtable	_jc_java_lang_NoSuchFieldException$vtable;
typedef const struct _jc_java_lang_NoSuchFieldException$vtype	_jc_java_lang_NoSuchFieldException$vtype;

// Class fields structure
struct _jc_java_lang_NoSuchFieldException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_NoSuchFieldException$fields_struct _jc_java_lang_NoSuchFieldException$class_fields;

// Constructors
extern void _jc_java_lang_NoSuchFieldException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_NoSuchFieldException$object *);
extern void _jc_java_lang_NoSuchFieldException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_NoSuchFieldException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_lang_NoSuchFieldException$vmethods {
};

// Vtable
struct _jc_java_lang_NoSuchFieldException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_NoSuchFieldException$vmethods	java_lang_NoSuchFieldException;
};

// Vtype
struct _jc_java_lang_NoSuchFieldException$vtype {
	_jc_type			type;
	_jc_java_lang_NoSuchFieldException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_NoSuchFieldException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_NoSuchFieldException$refs {
    _jc_java_lang_NoSuchFieldException$sub_refs	java_lang_NoSuchFieldException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_NoSuchFieldException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_NoSuchFieldException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_NoSuchFieldException$sub_nonrefs	java_lang_NoSuchFieldException;
};

// Object instance structure
struct _jc_java_lang_NoSuchFieldException$object {
	_jc_java_lang_NoSuchFieldException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_NoSuchFieldException$vtype	*vtype;
	_jc_java_lang_NoSuchFieldException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_NoSuchFieldException$vtype _jc_java_lang_NoSuchFieldException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_NoSuchFieldException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_NoSuchFieldException$class_object;

#endif	/* _JC_java_lang_NoSuchFieldException_H_ */

==> jc-1.4.6.tar.gz: java/lang/NoSuchFieldException.h <==
// public class java.lang.NoSuchFieldException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class b466c3d2a1fb976d java_lang_NoSuchFieldException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_lang_NoSuchFieldException_H_
#define _JC_java_lang_NoSuchFieldException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_NoSuchFieldException$sub_refs	_jc_java_lang_NoSuchFieldException$sub_refs;
typedef struct _jc_java_lang_NoSuchFieldException$sub_nonrefs	_jc_java_lang_NoSuchFieldException$sub_nonrefs;
typedef struct _jc_java_lang_NoSuchFieldException$refs	_jc_java_lang_NoSuchFieldException$refs;
typedef struct _jc_java_lang_NoSuchFieldException$nonrefs	_jc_java_lang_NoSuchFieldException$nonrefs;
typedef struct _jc_java_lang_NoSuchFieldException$object	_jc_java_lang_NoSuchFieldException$object;

typedef struct _jc_java_lang_NoSuchFieldException$fields_struct	_jc_java_lang_NoSuchFieldException$fields_struct;
typedef const struct _jc_java_lang_NoSuchFieldException$vmethods	_jc_java_lang_NoSuchFieldException$vmethods;
typedef const struct _jc_java_lang_NoSuchFieldException$vtable	_jc_java_lang_NoSuchFieldException$vtable;
typedef const struct _jc_java_lang_NoSuchFieldException$vtype	_jc_java_lang_NoSuchFieldException$vtype;

// Class fields structure
struct _jc_java_lang_NoSuchFieldException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_NoSuchFieldException$fields_struct _jc_java_lang_NoSuchFieldException$class_fields;

// Constructors
extern void _jc_java_lang_NoSuchFieldException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_NoSuchFieldException$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_NoSuchFieldException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_NoSuchFieldException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_NoSuchFieldException$vmethods {
};

// Vtable
struct _jc_java_lang_NoSuchFieldException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_NoSuchFieldException$vmethods	java_lang_NoSuchFieldException;
};

// Vtype
struct _jc_java_lang_NoSuchFieldException$vtype {
	_jc_type			type;
	_jc_java_lang_NoSuchFieldException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_NoSuchFieldException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_NoSuchFieldException$refs {
    _jc_java_lang_NoSuchFieldException$sub_refs	java_lang_NoSuchFieldException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_NoSuchFieldException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_NoSuchFieldException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_NoSuchFieldException$sub_nonrefs	java_lang_NoSuchFieldException;
};

// Object instance structure
struct _jc_java_lang_NoSuchFieldException$object {
	_jc_java_lang_NoSuchFieldException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_NoSuchFieldException$vtype	*vtype;
	_jc_java_lang_NoSuchFieldException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_NoSuchFieldException$vtype _jc_java_lang_NoSuchFieldException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_NoSuchFieldException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_NoSuchFieldException$class_object;

#endif	/* _JC_java_lang_NoSuchFieldException_H_ */
